@@ -23,10 +23,15 @@ __PACKAGE__->add_columns(
         data_type           => 'varchar',
         size                => 16,
         is_nullable         => 1,
+        default_value       => undef,
     },
     birthdate   => {
         data_type           => 'date',
     },
+    registered => {
+        data_type           => 'datetime',
+        default_value       => \'CURRENT_TIMESTAMP',
+    },
 );
 __PACKAGE__->set_primary_key( 'id' );
 __PACKAGE__->add_unique_constraint( [ qw( username ) ] );
